@@ -18,7 +18,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package WebFetch;
-$WebFetch::VERSION = '0.15.7';
+$WebFetch::VERSION = '0.15.8';
 
 use Carp qw(croak);
 use Getopt::Long;
@@ -69,9 +69,13 @@ Readonly::Hash my %redirect_params => (
     ul        => "style",
 );
 
-# file paths
+# file paths and class names
 Readonly::Scalar my $db_class => "DB_File";
-Readonly::Array my @yaml_class => qw(YAML::XS YAML YAML::PP YAML::Tiny YAML::Syck);
+Readonly::Array my @yaml_class => (
+      ( exists $ENV{WEBFETCH_YAML_CLASS} )
+    ? ( split " ", $ENV{WEBFETCH_YAML_CLASS} )
+    : qw(YAML::XS YAML::Syck YAML::PP YAML)
+);
 Readonly::Hash my %index_file => (
     db   => "id_index.db",
     lock => "id_index.lock",
@@ -224,6 +228,22 @@ sub _module_registry
 }
 ## critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 
+# load a YAML parser class from allowed list
+sub _load_yaml
+{
+    my $yaml_loaded;
+    foreach my $classname (@yaml_class) {
+        try {
+            ## no critic (BuiltinFunctions::ProhibitStringyEval)
+            eval "require $classname" or croak $@;
+            $classname->import(qw(LoadFile DumpFile));
+            $yaml_loaded = $classname;
+        };
+        last if $yaml_loaded;
+    }
+    return $yaml_loaded;
+}
+
 # return WebFetch (or subclass) version number
 sub version
 {
@@ -1308,16 +1328,7 @@ sub _save_check_index_yaml
     my $index_yaml_path = $self->{dir} . "/" . $index_file{yaml};
 
     # check if YAML module is available
-    my $yaml_loaded;
-    foreach my $classname (@yaml_class) {
-        try {
-            ## no critic (BuiltinFunctions::ProhibitStringyEval)
-            eval "require $classname" or croak $@;
-            $classname->import(qw(LoadFile DumpFile));
-            $yaml_loaded = $classname;
-        };
-        last if $yaml_loaded;
-    }
+    my $yaml_loaded = _load_yaml();
 
     # look up content in YAML index
     if ( $yaml_loaded and ( exists $savable->{url} ) and ( exists $savable->{index} ) ) {
@@ -1927,7 +1938,7 @@ WebFetch - Perl module to download/fetch and save information from the Web
 
 =head1 VERSION
 
-version 0.15.7
+version 0.15.8
 
 =head1 SYNOPSIS
 
@@ -2839,7 +2850,7 @@ Ian Kluft <https://github.com/ikluft>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 1998-2022 by Ian Kluft.
+This software is Copyright (c) 1998-2023 by Ian Kluft.
 
 This is free software, licensed under:
 
